__author__ = 'SHASHANK'

BANK_HOLIDAYS = ['2018-01-26', '2018-03-20', '2018-04-02', '2018-08-15',
                 '2018-08-22', '2018-10-02', '2018-12-25', '2018-04-01']


BSE_HOLIDAYS = ['2018-01-26', '2018-02-13', '2018-03-02', '2018-03-29',
                '2018-03-30', '2018-05-01', '2018-08-15', '2018-08-22',
                '2018-09-13', '2018-09-20', '2018-10-02', '2018-10-18',
                '2018-11-07', '2018-11-08', '2018-11-23', '2018-12-25',
                '2018-02-19', '2018-04-30', '2018-08-17', '2018-11-21']

MF_ALLOTMENT_TAT = {
    'Default': [0, 1],
    'F309-GR': [0, 2],
    '410-GR': [0, 2],
    'RELLFTPI-GR': [1, 0],
    'RGFEF-GR': [0, 1],
    'AXFXS153-GR': [0, 1],
    'EDGCGP-GR': [0, 1],
    'CPGP-GR': [0, 1],
    'CREQGP-GR': [0, 1],
    'RELRSFB-GR': [0, 1]
}